@@ -31,7 +31,7 @@ def zip_and_upload(client: CogniteClient, code_path: Path, file_name: str, data_
         id = data_set_id(client, data_set_name)
         file = client.files.upload(
             f"{zip_path}.zip",
-            name=file_name,
+            name=f"{file_name}.zip",
             external_id=file_name,
             overwrite=True,
             data_set_id=id,
